@@ -30,6 +30,10 @@ Cell.BEGIN_END_GROUP <- 3
 #' @export
 Cell.NEGATIVE <- 4
 
+#' @rdname Cell.BEGIN_GROUP
+#' @export
+Cell.INDENTED <- 8
+
 Cell <- R6::R6Class(
     "Cell",
     active=list(
@@ -80,7 +84,9 @@ Cell <- R6::R6Class(
             } else if (cellPB$has('d')) {
                 self$value <- cellPB$d
             } else if (cellPB$has('s')) {
-                self$value <- cellPB$s
+                v <- cellPB$s
+                Encoding(v) <- 'UTF-8'
+                self$value <- v
             } else if (cellPB$has('o')) {
                 if (cellPB$o == jamovi.coms.ResultsCell.Other$MISSING)
                     self$value <- NA
@@ -126,4 +132,3 @@ Cell <- R6::R6Class(
 
             cell
         }))
-
